@@ -3,7 +3,7 @@
  *
  * https://www.onlyoffice.com/
  *
- * Version: 9.1.0 (build:173)
+ * Version: 9.2.1 (build:43)
  */
 
 var editor=undefined;var navigator={};navigator.userAgent="chrome";window.location={};window.location.protocol="";window.location.host="";window.location.href="";window.location.pathname="";window.XMLHttpRequest=function(){};window.NATIVE_EDITOR_ENJINE=true;window.NATIVE_EDITOR_ENJINE_SYNC_RECALC=true;var document={};var Asc={};var AscFonts={};var AscCommon={};var AscFormat={};var AscDFH={};var AscCH={};var AscCommonExcel={};var AscCommonWord={};var AscMath={};var AscCommonSlide={};
@@ -20,4 +20,4 @@ document.createComment=function(){return undefined};document.documentElement=_nu
 function NativeCreateApi(options){window.NATIVE_DOCUMENT_TYPE=window.native.GetEditorType();Api=null;var configApi={};if(options&&undefined!==options["translate"])configApi["translate"]=options["translate"];switch(window.NATIVE_DOCUMENT_TYPE){case "document":case "presentation":{Api=new window["Asc"]["asc_docs_api"](configApi);if(options&&options["documentLayout"]&&undefined!==options["documentLayout"]["openedAt"])Api.setOpenedAt(options["documentLayout"]["openedAt"]);if(options&&options["documentLayout"]&&
 options["documentLayout"]["headingsColor"])if(window["AscWord"]&&window["AscWord"]["setDefaultHeadingColorStr"])window["AscWord"]["setDefaultHeadingColorStr"](options["documentLayout"]["headingsColor"]);break}case "spreadsheet":{Api=new window["Asc"]["spreadsheet_api"](configApi);break}case "pdf":{Api=new window["Asc"]["PDFEditorApi"](configApi);break}case "visio":{Api=new window["Asc"]["VisioEditorApi"](configApi);break}default:break}if(options&&undefined!==options["locale"])Api.asc_setLocale(options["locale"])}
 function NativeOpenFileData(data,version,xlsx_file_path,options){NativeCreateApi(options);switch(window.NATIVE_DOCUMENT_TYPE){case "visio":case "document":case "presentation":{Api.asc_nativeOpenFile(data,version);break}case "spreadsheet":{Api.asc_nativeOpenFile(data,version,undefined,xlsx_file_path);break}case "pdf":{Api.asc_nativeOpenFile(data,version);break}default:break}}var clearTimeout=window.clearTimeout=function(){};var setTimeout=window.setTimeout=function(){};
-var clearInterval=window.clearInterval=function(){};var setInterval=window.setInterval=function(){};var console={log:function(param){window.native&&window.native.ConsoleLog(param)},time:function(param){},timeEnd:function(param){},warn:function(){},error:function(){}};var performance=window.performance=function(){var basePerformanceOffset=Date.now();return{now:function(){return Date.now()-basePerformanceOffset}}}();
+var clearInterval=window.clearInterval=function(){};var setInterval=window.setInterval=function(){};var console={log:function(param){window.native&&window.native.ConsoleLog(param)},time:function(param){},timeEnd:function(param){},warn:function(){},error:function(){window.native&&window.native.ConsoleLog("[error]: "+param)}};var performance=window.performance=function(){var basePerformanceOffset=Date.now();return{now:function(){return Date.now()-basePerformanceOffset}}}();
